netapp_ontap.models.security_association_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_association_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityAssociationResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityAssociationResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cipher_suite: str GET POST PATCH`

    Cipher suite for the security association.

    Valid choices:

    - suite_aescbc
    - suiteb_gcm256
    - suiteb_gmac256
  `ike: SecurityAssociationIke GET POST PATCH`

    Objects containing parameters specific to IKE (Internet Key Exchange) security association.

  `ipsec: SecurityAssociationIpsec GET POST PATCH`

    Objects containing parameters specific to IPsec security association.

  `lifetime: Size GET POST PATCH`

    Lifetime for the security association in seconds.

  `local_address: str GET POST PATCH`

    Local address of the security association.

  `node: Node GET POST PATCH`

    The node field of the security_association_response_records.

  `policy_name: str GET POST PATCH`

    Policy name for the security association.

  `remote_address: str GET POST PATCH`

    Remote address of the security association.

  `scope: str GET POST PATCH`

    The scope field of the security_association_response_records.

  `svm: Svm GET POST PATCH`

    The svm field of the security_association_response_records.

  `type: str GET POST PATCH`

    Type of security association, it can be IPsec or IKE (Internet Key Exchange).

    Valid choices:

    - ipsec
    - ike
  `uuid: str GET POST PATCH`

    Unique identifier of the security association.